@@ -105,6 +105,8 @@ class MsgFields(ConstantDict):
     TASKS_GEOIP = "geoip_task"
     TASKS_HTTP_STATUS = "http_status_task"
     TASKS_RESOLVER = "resolver_task"
+    TASKS_WEB_FINGERPRINT = "web_fingerprint_task"
+    TASKS_OS_FINGERPRINT = "os_fingerprint_task"
     TASKS_WHOIS = "whois_task"
 
 
@@ -113,6 +115,8 @@ class MsgValues(ConstantDict):
     HTTP_CONTENT_FILE = "content"
     HTTP_HEADERS_FILE = "headers"
 
+    NMAP_STATUS_UP = "up"
+
 
 class MsgErrs(ConstantDict):
     FILE_IO_ERROR = "FILE_IO_ERROR::{0}"
